@@ -10,11 +10,12 @@ import re
 import subprocess  # nosec
 import uuid
 from shutil import which
-from typing import Callable, Dict, List, Optional, Tuple, Type, TypeVar
+from typing import Callable, Dict, List, Optional, Tuple, Type, TypeVar, cast
 from uuid import UUID
 
 import pkg_resources
 import semver
+from memoization import cached
 from onefuzztypes import enums, models, primitives, requests, responses
 from pydantic import BaseModel
 from six.moves import input  # workaround for static analysis
@@ -33,6 +34,8 @@ DEFAULT = {
 # This was generated randomly and should be preserved moving forwards
 ONEFUZZ_GUID_NAMESPACE = uuid.UUID("27f25e3f-6544-4b69-b309-9b096c5a9cbc")
 
+ONE_HOUR_IN_SECONDS = 3600
+
 DEFAULT_LINUX_IMAGE = "Canonical:UbuntuServer:18.04-LTS:latest"
 DEFAULT_WINDOWS_IMAGE = "MicrosoftWindowsDesktop:Windows-10:rs5-pro:latest"
 
@@ -146,6 +149,7 @@ class Files(Endpoint):
 
     endpoint = "files"
 
+    @cached(ttl=ONE_HOUR_IN_SECONDS)
     def _get_client(self, container: str) -> ContainerWrapper:
         sas = self.onefuzz.containers.get(container).sas_url
         return ContainerWrapper(sas)
@@ -166,7 +170,8 @@ class Files(Endpoint):
         """ get a file from a container """
         self.logger.debug("getting file from container: %s:%s", container, filename)
         client = self._get_client(container)
-        return client.download_blob(filename)
+        downloaded = cast(bytes, client.download_blob(filename))
+        return downloaded
 
     def upload_file(
         self, container: str, file_path: str, blob_name: Optional[str] = None
@@ -666,8 +671,16 @@ class Tasks(Endpoint):
         analyzer_env: Optional[Dict[str, str]] = None,
         tags: Optional[Dict[str, str]] = None,
         prereq_tasks: Optional[List[UUID]] = None,
+        debug: Optional[List[enums.TaskDebugFlag]] = None,
+        ensemble_sync_delay: Optional[int] = None,
     ) -> models.Task:
-        """ Create a task """
+        """
+        Create a task
+
+        :param bool ensemble_sync_delay: Specify duration between
+            syncing inputs during ensemble fuzzing (0 to disable).
+        """
+
         self.logger.debug("creating task: %s", task_type)
 
         job_id_expanded = self._disambiguate_uuid(
@@ -725,10 +738,12 @@ class Tasks(Endpoint):
                 check_asan_log=check_asan_log,
                 check_debugger=check_debugger,
                 check_retry_count=check_retry_count,
+                ensemble_sync_delay=ensemble_sync_delay,
             ),
             pool=models.TaskPool(count=vm_count, pool_name=pool_name),
             containers=containers_submit,
             tags=tags,
+            debug=debug,
         )
 
         return self.create_with_config(config)
@@ -983,6 +998,28 @@ class Node(Endpoint):
             data=requests.NodeGet(machine_id=machine_id_expanded),
         )
 
+    def update(
+        self,
+        machine_id: UUID_EXPANSION,
+        *,
+        debug_keep_node: Optional[bool] = None,
+    ) -> responses.BoolResult:
+        self.logger.debug("update node: %s", machine_id)
+        machine_id_expanded = self._disambiguate_uuid(
+            "machine_id",
+            machine_id,
+            lambda: [str(x.machine_id) for x in self.list()],
+        )
+
+        return self._req_model(
+            "POST",
+            responses.BoolResult,
+            data=requests.NodeUpdate(
+                machine_id=machine_id_expanded,
+                debug_keep_node=debug_keep_node,
+            ),
+        )
+
     def list(
         self,
         *,
