@@ -5,7 +5,7 @@
 
 from typing import Dict, List, Optional
 
-from onefuzztypes.enums import ContainerType, TaskType
+from onefuzztypes.enums import ContainerType, TaskDebugFlag, TaskType
 from onefuzztypes.models import Job, NotificationConfig
 from onefuzztypes.primitives import Container, Directory, File
 
@@ -46,6 +46,8 @@ class Libfuzzer(Command):
         tags: Optional[Dict[str, str]] = None,
         check_retry_count: Optional[int] = None,
         crash_report_timeout: Optional[int] = None,
+        debug: Optional[List[TaskDebugFlag]] = None,
+        ensemble_sync_delay: Optional[int] = None,
     ) -> None:
 
         fuzzer_containers = [
@@ -54,6 +56,11 @@ class Libfuzzer(Command):
             (ContainerType.inputs, containers[ContainerType.inputs]),
         ]
         self.logger.info("creating libfuzzer task")
+
+        # disable ensemble sync if only one VM is used
+        if ensemble_sync_delay is None and vm_count == 1:
+            ensemble_sync_delay = 0
+
         fuzzer_task = self.onefuzz.tasks.create(
             job.job_id,
             TaskType.libfuzzer_fuzz,
@@ -67,6 +74,8 @@ class Libfuzzer(Command):
             target_env=target_env,
             target_workers=target_workers,
             tags=tags,
+            debug=debug,
+            ensemble_sync_delay=ensemble_sync_delay,
         )
 
         coverage_containers = [
@@ -88,6 +97,7 @@ class Libfuzzer(Command):
             target_env=target_env,
             tags=tags,
             prereq_tasks=[fuzzer_task.task_id],
+            debug=debug,
         )
 
         report_containers = [
@@ -114,6 +124,7 @@ class Libfuzzer(Command):
             prereq_tasks=[fuzzer_task.task_id],
             target_timeout=crash_report_timeout,
             check_retry_count=check_retry_count,
+            debug=debug,
         )
 
     def basic(
@@ -141,8 +152,15 @@ class Libfuzzer(Command):
         existing_inputs: Optional[Container] = None,
         dryrun: bool = False,
         notification_config: Optional[NotificationConfig] = None,
+        debug: Optional[List[TaskDebugFlag]] = None,
+        ensemble_sync_delay: Optional[int] = None,
     ) -> Optional[Job]:
-        """ Basic libfuzzer job """
+        """
+        Basic libfuzzer job
+
+        :param bool ensemble_sync_delay: Specify duration between
+            syncing inputs during ensemble fuzzing (0 to disable).
+        """
 
         # verify containers exist
         if existing_inputs:
@@ -207,6 +225,8 @@ class Libfuzzer(Command):
             tags=helper.tags,
             crash_report_timeout=crash_report_timeout,
             check_retry_count=check_retry_count,
+            debug=debug,
+            ensemble_sync_delay=ensemble_sync_delay,
         )
 
         self.logger.info("done creating tasks")
